@@ -12,53 +12,53 @@ class ThreeSourcesTC(BaseMSTC):
 
     def test_projects_list(self):
         rset = self.execute('Project P')
-        self.assertEquals(len(rset), 6)
+        self.assertEqual(len(rset), 6)
 
     def test_nonregr1(self):
         rset = self.execute('Any X WHERE X eid %(x)s, V version_of X, V in_state S, S name "published"',
                             {'x': self.ip1eid})
-        self.assertEquals(rset.rows, [])
+        self.assertEqual(rset.rows, [])
         self.change_state(self.ip1v1eid, 'published')
         rset = self.execute('Any X WHERE X eid %(x)s, V version_of X, V in_state S, S name "published"',
                             {'x': self.ip1eid})
-        self.assertEquals(len(rset.rows), 1)
-        self.assertEquals(rset.rows[0][0], self.ip1eid)
+        self.assertEqual(len(rset.rows), 1)
+        self.assertEqual(rset.rows[0][0], self.ip1eid)
         rset = self.execute('Any X WHERE X eid %(x)s, V version_of X, V in_state S, S name "published"',
                             {'x': self.ip2eid})
-        self.assertEquals(rset.rows, [])
+        self.assertEqual(rset.rows, [])
         self.change_state(self.ip2v1eid, 'published')
         rset = self.execute('Any X WHERE X eid %(x)s, V version_of X, V in_state S, S name "published"',
                             {'x': self.ip2eid})
-        self.assertEquals(len(rset.rows), 1)
+        self.assertEqual(len(rset.rows), 1)
         # same test with entities from the external source
         iep1eid = self.extid2eid(ep1eid, 'Project')
         iep1v1eid = self.extid2eid(ep1v1eid, 'Project')
         rset = self.execute('Any X WHERE X eid %(x)s, V version_of X, V in_state S, S name "published"',
                             {'x': iep1eid})
-        self.assertEquals(rset.rows, [])
+        self.assertEqual(rset.rows, [])
         # XXX don't work anymore since changing state is done by adding TrInfo which isn't currently
         #     imported from external sources
         self.assertRaises(MultiSourcesError, self.change_state, iep1v1eid, 'published')
         #self.change_state(iep1v1eid, 'published')
         # rset = self.execute('Any X WHERE X eid %(x)s, V version_of X, V in_state S, S name "published"',
         #                     {'x': iep1eid})
-        # self.assertEquals(len(rset.rows), 1, rset)
-        # self.assertEquals(rset.rows[0][0], iep1eid)
+        # self.assertEqual(len(rset.rows), 1, rset)
+        # self.assertEqual(rset.rows[0][0], iep1eid)
         # iep2eid = self.extid2eid(ep2eid, 'Project')
         # iep2v1eid = self.extid2eid(ep2v1eid, 'Project')
         # rset = self.execute('Any X WHERE X eid %(x)s, V version_of X, V in_state S, S name "published"',
         #                     {'x': iep2eid})
-        # self.assertEquals(rset.rows, [])
+        # self.assertEqual(rset.rows, [])
         # self.change_state(iep2v1eid, 'published')
         # rset = self.execute('Any X WHERE X eid %(x)s, V version_of X, V in_state S, S name "published"',
         #                     {'x': iep2eid})
-        # self.assertEquals(len(rset.rows), 1)
+        # self.assertEqual(len(rset.rows), 1)
 
     def test_nonregr2(self):
         ip2v1 = self.execute('Any X WHERE X eid %(x)s', {'x': self.ip2v1eid}).get_entity(0, 0)
         rset = ip2v1.depends_on_rset()
-        self.assertEquals(len(rset.rows), 1)
-        self.assertEquals(rset.rows[0][0], self.ip1v1eid)
+        self.assertEqual(len(rset.rows), 1)
+        self.assertEqual(rset.rows[0][0], self.ip1v1eid)
 
     def test_nonregr3(self):
         self.execute('Any V,DATE ORDERBY version_sort_value(N) '
@@ -71,7 +71,7 @@ class ThreeSourcesTC(BaseMSTC):
         self.fire_transition(self.ip1t1eid, 'start')
         self.commit()
         ip1v1 = self.execute('Any X WHERE X eid %(x)s', {'x': self.ip1v1eid}).get_entity(0, 0)
-        self.assertEquals(ip1v1.cw_adapt_to('IWorkflowable').state, 'dev')
+        self.assertEqual(ip1v1.cw_adapt_to('IWorkflowable').state, 'dev')
 
     def test_nonregr5(self):
         self.fire_transition(self.ip1t1eid, 'start')
@@ -88,7 +88,7 @@ class ThreeSourcesTC(BaseMSTC):
                             'WHERE B type TT, B priority PR, B in_state S, B creation_date CD, B done_in V?, V num VN, B concerns P, P eid %s'
                             % self.ip1eid)
         rset.rows[0][4] = 'STATE'
-        self.assertEquals(rset.rows, [[self.ip1t1eid, u'bug', timedelta(0), u'normal', 'STATE', self.ip1v1eid]])
+        self.assertEqual(rset.rows, [[self.ip1t1eid, u'bug', timedelta(0), u'normal', 'STATE', self.ip1v1eid]])
 
     def test_nonregr8(self):
         self.execute('Any SN WHERE X has_text "toto", X in_state S, S name SN, X is IN (Project, Version, Transition)')
