@@ -47,7 +47,7 @@ class ProjectTC(TrackerBaseTC):
 
     def test_tickets_rql(self):
         self.execute(self.cubicweb.active_tickets_rql()) # just check rql validity
-        self.execute(self.cubicweb.tickets_rql()) # just check rql validity
+        self.execute(*self.cubicweb.tickets_rql()) # just check rql validity
 
     def test_versions_in_state(self):
         v1 = self.create_version(u'0.0.0').get_entity(0, 0)
@@ -108,7 +108,7 @@ class VersionTC(TrackerBaseTC):
         self.t1 = self.create_ticket(u"enchancement1", u'0.0.0').get_entity(0, 0)
 
     def test_entity(self):
-        self.execute(self.v.tickets_rql()) # just check rql validity
+        self.execute(*self.v.tickets_rql()) # just check rql validity
 
     def _test_anon_actions(self, with_hist=True):
         self.login('anon')
@@ -301,7 +301,8 @@ class VersionTC(TrackerBaseTC):
     def test_duplicated_version(self):
         ex = self.assertRaises(ValidationError, self.create_version, u'0.0.0')
         self.assertEqual(ex.errors,
-                          {'num': u'0.0.0 release number already exists for the project cubicweb'})
+                         {'num': u'version 0.0.0 already exists for project cubicweb',
+                          'version_of': u'version 0.0.0 already exists for project cubicweb'})
 
     def test_status_change_form(self):
         req = self.request()
