@@ -76,7 +76,7 @@ _pvs.tag_object_of(('*', 'todo_by', 'CWUser'), 'relations')
 uicfg.primaryview_display_ctrl.tag_object_of(
     ('*', 'todo_by', 'CWUser'),
     {'vid': 'list', 'label': _('working on release(s):'), 'limit': False,
-     'filter': lambda rset: rset.filtered_rset(lambda x: x.state == u'dev'),
+     'filter': lambda rset: rset.filtered_rset(lambda x: x.cw_adapt_to('IWorkflowable').state == u'dev'),
      })
 
 _abaa = uicfg.actionbox_appearsin_addmenu
