@@ -8,7 +8,7 @@ __docformat__ = "restructuredtext en"
 
 from datetime import datetime
 
-from cubicweb.selectors import is_instance, match_transition
+from cubicweb.selectors import is_instance, match_transition, attribute_edited
 from cubicweb.web import uicfg, formfields
 from cubicweb.web.views import workflow, editviews
 
@@ -54,9 +54,11 @@ _affk.tag_attribute(('Ticket', 'priority'), {'sort': False})
 _affk.tag_subject_of(('Ticket', 'done_in', '*'), {'sort': False,
                                                   'choices': ticket_done_in_choices})
 
+from cubicweb.web.formfields import eid_param, role_name
 
 class VersionChangeStateForm(workflow.ChangeStateForm):
-    __select__ = is_instance('Version') & match_transition('publish')
+    __select__ = is_instance('Version') & (match_transition('publish')
+                                           | attribute_edited('publication_date'))
 
     publication_date = formfields.DateField(eidparam=True, role='subject',
                                             fallback_on_none_attribute=True,
