@@ -18,6 +18,8 @@ from cubicweb import tags
 from cubicweb.web import component, uicfg
 from cubicweb.web.views import tabs, baseviews
 
+from cubes.tracker.entities import attr_tuple
+
 _pvdc = uicfg.primaryview_display_ctrl
 _pvdc.tag_attribute(('Project', 'summary'), {'showlabel': False})
 _pvdc.tag_attribute(('Project', 'description'), {'showlabel': False})
@@ -35,6 +37,8 @@ class ProjectPrimaryView(tabs.TabbedPrimaryView):
 _pvs = uicfg.primaryview_section
 _pvs.tag_attribute(('Project', 'name'), 'hidden')
 # XXX keep '*', not Project to match other target types added in eg forge
+_pvs.tag_object_of(('*', 'version_of', 'Project'), 'hidden')
+_pvs.tag_object_of(('*', 'concerns', 'Project'), 'hidden')
 _pvs.tag_subject_of(('Project', 'uses', '*'), 'attributes')
 _pvs.tag_object_of(('Project', 'uses', '*'), 'hidden')
 _pvs.tag_object_of(('Project', 'subproject_of', '*'), 'hidden')
@@ -69,7 +73,7 @@ class ProjectTicketsTab(EntityView):
         entity = self.cw_rset.get_entity(row, col)
         # optimization: prefetch project's to fill entity / relations cache
         entity.reverse_version_of
-        rset = self._cw.execute(entity.tickets_rql(limit=1))
+        rset = self._cw.execute(*attr_tuple(entity, 'tickets_rql', limit=1))
         self._cw.form['actualrql'] = entity.active_tickets_rql()
         self.wview('editable-initialtable', rset, 'null',
                    subvid='incontext', displayactions=1,
@@ -79,38 +83,34 @@ class ProjectTicketsTab(EntityView):
 
 # contextual components ########################################################
 
-class ProjectRoadmapVComponent(component.EntityVComponent):
+class ProjectRoadmapComponent(component.EntityCtxComponent):
     """display the latest published version and in preparation version"""
     __regid__ = 'roadmap'
-    __select__ = (component.EntityVComponent.__select__ &
+    __select__ = (component.EntityCtxComponent.__select__ &
                   authenticated_user() & is_instance('Project') &
                   has_related_entities('version_of', 'object'))
     context = 'navcontenttop'
-    title = _('Version_plural')
     order = 10
 
-    def cell_call(self, row, col, view=None):
-        self.cw_rset.get_entity(row, col).view('roadmap', w=self.w)
+    def render_body(self, w):
+        self.entity.view('roadmap', w=w)
 
 
-class ProjectTreeVComponent(component.EntityVComponent):
+class ProjectTreeComponent(component.EntityCtxComponent):
+    """display project/subprojects tree"""
     __regid__ = 'projecttree'
-    title = _('project tree')
-    __select__ = (component.EntityVComponent.__select__ &
+    __select__ = (component.EntityCtxComponent.__select__ &
                   is_instance('Project') &
                   score_entity(lambda x: x.cw_adapt_to('ITree').children()))
+    title = _('Project tree')
     context = 'navcontentbottom'
 
-    def cell_call(self, row, col, view=None):
+    def render_body(self, w):
         entity = self.cw_rset.get_entity(row, col)
-        rset = entity.children(entities=False)
-        if rset:
-            self.w(u'<div class="section">')
-            self.w(tags.h2(self._cw._('Project tree')))
-            treeid = 'project_tree_%s' % entity.eid
-            self.w(self.view('treeview', rset=rset, treeid=treeid,
-                             initial_thru_ajax=True))
-            self.w(u'</div>')
+        rset = entity.cw_adapt_to('ITree').children(entities=False)
+        treeid = 'project_tree_%s' % entity.eid
+        self.view('treeview', rset=rset, treeid=treeid,
+                  initial_thru_ajax=True, w=w)
 
 
 # secondary views ##############################################################
@@ -243,24 +243,23 @@ class ProjectStatsView(EntityStartupView):
         w(u'</table>')
 
 
-class SubscribeToReleasesComponent(component.EntityVComponent):
-    """link to subscribe to rss feed for published versions of project
-    """
+class SubscribeToReleasesComponent(component.EntityCtxComponent):
+    """link to subscribe to rss feed for published versions of project"""
+
     __regid__ = 'projectreleasesubscriberss'
-    __select__ = (component.EntityVComponent.__select__ &
+    __select__ = (component.EntityCtxComponent.__select__ &
                   is_instance('Project'))
     context = 'ctxtoolbar'
 
-    def cell_call(self, row, col, view=None):
-        entity = self.cw_rset.get_entity(row, col)
+    def render_body(self, w):
         label = self._cw._(u'Subscribe to project releases')
         logo = u'<img src="%s" alt="%s"/>' % (
             self._cw.uiprops['RSS_LOGO_16'], label)
         rql = 'Any V, VN ORDERBY VN DESC WHERE V version_of P, P eid %s, ' \
-              'V in_state S, S name "published", V num VN' % entity.eid
+              'V in_state S, S name "published", V num VN' % self.entity.eid
         # XXX <project>/versions/rss ?
         url = self._cw.build_url('view', vid='rss', rql=rql)
-        self.w(u'<a href="%s" title="%s" class="toolbarButton">%s</a>' % (
+        w(u'<a href="%s" title="%s" class="toolbarButton">%s</a>' % (
             xml_escape(url), label, logo))
 
 
