@@ -21,14 +21,9 @@ _pvs = uicfg.primaryview_section
 
 _pvs.tag_attribute(('Ticket', 'title'), 'hidden')
 _pvs.tag_attribute(('Ticket', 'description'), 'attributes')
-
-_pvs.tag_subject_of(('Ticket', 'concerns', 'Project'), 'hidden')
-_pvs.tag_object_of(('Ticket', 'concerns', 'Project'), 'hidden')
-_pvs.tag_subject_of(('Ticket', 'done_in', 'Version'), 'attributes')
-_pvs.tag_object_of(('Ticket', 'done_in', 'Version'), 'attributes')
-
+_pvs.tag_subject_of(('Ticket', 'concerns', '*'), 'hidden')
+_pvs.tag_subject_of(('Ticket', 'done_in', '*'), 'attributes')
 _pvs.tag_subject_of(('Ticket', 'appeared_in', '*'), 'sideboxes')
-_pvs.tag_object_of(('Ticket', 'appeared_in', '*'), 'hidden')
 _pvs.tag_subject_of(('Ticket', 'depends_on', '*'), 'sideboxes')
 _pvs.tag_object_of(('*', 'depends_on', 'Ticket'), 'sideboxes')
 
